@@ -6,6 +6,7 @@
 */
 
 #ifndef PACKAGESTRUCTURETEST_H
+#define PACKAGESTRUCTURETEST_H
 
 #include <QTest>
 
@@ -17,11 +18,11 @@ class QueryTest : public QObject
 
 private Q_SLOTS:
     void initTestCase();
-    void cleanupTestCase();
     void installAndQuery();
+    void queryCustomPlugin();
 
 private:
-    KPackage::Package ps;
+    const QString packageFormat = "Plasma/TestKPackageInternalPlasmoid";
     QDir m_dataDir;
 };
 
